@@ -418,7 +418,6 @@ void Board::addMarker(const Pos& pos, const QString& spriteKey) {
 
 void Board::updateTheme() {
 	delete m_background;
-	qDebug()<<"background key " << backgroundKey;
 	if ( renderer->spriteExists ( backgroundKey ) ) {
 		m_background = new Item ( renderer, backgroundKey, this, Pos() );
 		m_background->setZValue ( backgroundZValue );
@@ -474,6 +473,9 @@ void Board::updateTheme() {
 }
 
 void Board::updateGraphics() {
+	if (sceneRect().isEmpty()) {
+	    return;
+	}
 	if ( m_background )
 		m_background->setRenderSize ( sceneRect().size().toSize() );
 	QSizeF tileSize = renderer->boundsOnSprite ( whiteTileKey ).size();
